@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 from qtpy import QtCore, QtGui
 
@@ -39,7 +37,7 @@ class StandardItem(QtGui.QStandardItem):
         return item
 
     def set_icon(self, icon: gui.icon.IconType):
-        """set the icon for the action
+        """Set the icon for the action.
 
         Args:
             icon: icon to use
