@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 from typing import List
 import warnings
@@ -14,9 +12,11 @@ def string_to_num_array(array: str) -> List[float]:
 
 
 def deprecated(func):
-    """This is a decorator which can be used to mark functions
-    as deprecated. It will result in a warning being emitted
-    when the function is used."""
+    """A decorator which can be used to mark functions as deprecated.
+
+    It will result in a warning being emitted
+    when the function is used.
+    """
 
     @functools.wraps(func)
     def new_func(*args, **kwargs):
