@@ -1,9 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-
-for full list, see:
-- https://cdn.materialdesignicons.com/3.0.39/
-"""
 
 import logging
 
