@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 from qtpy import QtWidgets
 
@@ -34,6 +32,12 @@ class AbstractSpinBox(QtWidgets.QAbstractSpinBox):
         self.setLineEdit(widgets.LineEdit())
         self.setGroupSeparatorShown(True)
 
+    def serialize_fields(self):
+        return dict(
+            button_symbols=self.get_button_symbols(),
+            correction_mode=self.get_correction_mode(),
+        )
+
     def is_valid(self) -> bool:
         return self.hasAcceptableInput()
 
@@ -41,7 +45,7 @@ class AbstractSpinBox(QtWidgets.QAbstractSpinBox):
         self.lineEdit().setValidator(validator)
 
     def get_button_symbols(self) -> str:
-        """returns button symbol type
+        """Return button symbol type.
 
         possible values are "none", "up_down", "plus_minus"
 
@@ -51,7 +55,7 @@ class AbstractSpinBox(QtWidgets.QAbstractSpinBox):
         return SYMBOLS.inv[self.buttonSymbols()]
 
     def set_button_symbols(self, mode: str):
-        """sets button symbol type
+        """Set button symbol type.
 
         possible values are "none", "up_down", "plus_minus"
 
@@ -66,7 +70,7 @@ class AbstractSpinBox(QtWidgets.QAbstractSpinBox):
         self.setButtonSymbols(SYMBOLS[mode])
 
     def set_correction_mode(self, mode: str):
-        """sets correction mode
+        """Set correction mode.
 
         possible values are "to_previous", "to_nearest"
 
@@ -81,7 +85,7 @@ class AbstractSpinBox(QtWidgets.QAbstractSpinBox):
         self.setCorrectionMode(CORRECTION_MODES[mode])
 
     def get_correction_mode(self) -> str:
-        """returns correction mode
+        """Return correction mode.
 
         possible values are "to_previous", "to_nearest"
 
@@ -91,7 +95,7 @@ class AbstractSpinBox(QtWidgets.QAbstractSpinBox):
         return CORRECTION_MODES.inv[self.correctionMode()]
 
     def set_step_type(self, mode: str):
-        """sets step type
+        """Set step type.
 
         possible values are "default", "adaptive"
 
@@ -106,7 +110,7 @@ class AbstractSpinBox(QtWidgets.QAbstractSpinBox):
         self.setStepType(STEP_TYPES[mode])
 
     def get_step_type(self) -> str:
-        """returns step type
+        """Return step type.
 
         possible values are "default", "adaptive"
 
