@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 import functools
 from typing import Iterable, Optional, Union, List
@@ -64,16 +62,14 @@ class HeaderView(QtWidgets.QHeaderView):
             self.setSectionResizeMode(col, MODES[mode])
 
     def section_labels(self) -> List[str]:
-        model = self.parent().model()
+        model = self.model()
         return [
             model.headerData(i, QtCore.Qt.Horizontal, QtCore.Qt.DisplayRole)
             for i in range(self.count())
         ]
 
     def contextMenuEvent(self, event):
-        """
-        context menu for our files tree
-        """
+        """Context menu for our files tree."""
         menu = widgets.Menu(parent=self)
         for i, header_label in enumerate(self.section_labels()[1:], start=1):
             act = menu.addAction(header_label)
@@ -88,7 +84,7 @@ class HeaderView(QtWidgets.QHeaderView):
         self.section_vis_changed.emit(i, hide)
         self.setSectionHidden(i, hide)
 
-    def set_sizes(self, sizes: Iterable):
+    def set_sizes(self, sizes: Iterable[Optional[int]]):
         for i, size in enumerate(sizes):
             if size is not None:
                 self.resizeSection(i, size)
