@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 from typing import Optional
 
@@ -37,14 +35,11 @@ class LineEdit(QtWidgets.QLineEdit):
         self.set_read_only(read_only)
 
     def __repr__(self):
-        return f"LineEdit: {self.__getstate__()}"
+        return f"LineEdit: {self.serialize_fields()}"
 
-    def __getstate__(self):
+    def serialize_fields(self):
         return dict(
             text=self.text(),
-            enabled=self.isEnabled(),
-            tooltip=self.toolTip(),
-            statustip=self.statusTip(),
             font=gui.Font(self.font()),
             validator=self.validator(),
             max_length=self.maxLength(),
@@ -83,7 +78,7 @@ class LineEdit(QtWidgets.QLineEdit):
         self.setText(text)
 
     def set_read_only(self, value: bool = True):
-        """set test to read only
+        """Set text to read-only.
 
         Args:
             value: True, for read-only, otherwise False
@@ -113,7 +108,7 @@ class LineEdit(QtWidgets.QLineEdit):
         self.set_background_color(color)
 
     def set_echo_mode(self, mode: str):
-        """set echo mode
+        """Set echo mode.
 
         Valid values are "normal", "no_echo", "password", "echo_on_edit"
 
@@ -128,7 +123,7 @@ class LineEdit(QtWidgets.QLineEdit):
         self.setEchoMode(ECHO_MODES[mode])
 
     def get_echo_mode(self) -> str:
-        """returns echo mode
+        """Return echo mode.
 
         possible values are "normal", "no_echo", "password", "echo_on_edit"
 
