@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 from qtpy import QtWidgets
 
@@ -63,7 +61,7 @@ class SizePolicy(QtWidgets.QSizePolicy):
         self.setRetainSizeWhenHidden(state["retain_size_when_hidden"])
 
     def get_horizontal_policy(self) -> str:
-        """returns size policy
+        """Return size policy.
 
         possible values are "fixed", "minimum", "maximum", "preferred",
         "expanding", "minimum_expanding" and "ignored"
@@ -74,7 +72,7 @@ class SizePolicy(QtWidgets.QSizePolicy):
         return SIZE_POLICIES.inv[self.horizontalPolicy()]
 
     def set_horizontal_policy(self, mode: str) -> None:
-        """sets the horizontal policy
+        """Set the horizontal policy.
 
         possible values are "fixed", "minimum", "maximum", "preferred",
         "expanding", "minimum_expanding" and "ignored"
@@ -85,7 +83,7 @@ class SizePolicy(QtWidgets.QSizePolicy):
         self.setHorizontalPolicy(SIZE_POLICIES[mode])
 
     def get_vertical_policy(self) -> str:
-        """returns size policy
+        """Return size policy.
 
         possible values are "fixed", "minimum", "maximum", "preferred",
         "expanding", "minimum_expanding" and "ignored"
@@ -96,7 +94,7 @@ class SizePolicy(QtWidgets.QSizePolicy):
         return SIZE_POLICIES.inv[self.verticalPolicy()]
 
     def set_vertical_policy(self, mode: str) -> None:
-        """sets the horizontal policy
+        """Set the horizontal policy.
 
         possible values are "fixed", "minimum", "maximum", "preferred",
         "expanding", "minimum_expanding" and "ignored"
@@ -107,7 +105,7 @@ class SizePolicy(QtWidgets.QSizePolicy):
         self.setVerticalPolicy(SIZE_POLICIES[mode])
 
     def get_control_type(self) -> str:
-        """returns control type
+        """Return control type.
 
         possible values are "default", "buttonbox", "checkbox", "combobox", "frame",
         "groupbox", "label", "line", "lineedit", "pushbutton", "radiobutton", "slider",
@@ -119,7 +117,7 @@ class SizePolicy(QtWidgets.QSizePolicy):
         return CONTROL_TYPES.inv[self.controlType()]
 
     def set_control_type(self, mode: str) -> None:
-        """sets the control type
+        """Set the control type.
 
         possible values are "default", "buttonbox", "checkbox", "combobox", "frame",
         "groupbox", "label", "line", "lineedit", "pushbutton", "radiobutton", "slider",
