@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 from typing import Optional
 
@@ -57,7 +55,7 @@ class TabBar(QtWidgets.QTabBar):
     def __setitem__(self, index, value):
         self.set_tab(index[0], index[1], value)
 
-    def __getstate__(self):
+    def serialize_fields(self):
         return dict(
             movable=self.isMovable(),
             document_mode=self.documentMode(),
@@ -84,7 +82,7 @@ class TabBar(QtWidgets.QTabBar):
         self.on_detach.emit(self.tabAt(event.pos()), self.mouse_cursor.pos())
 
     def set_icon_size(self, size: int) -> None:
-        """Set the icon size for the tabs
+        """Set the icon size for the tabs.
 
         Args:
             size: height/width of the icons
@@ -97,7 +95,7 @@ class TabBar(QtWidgets.QTabBar):
         self.setTabButton(index, POSITIONS[position], widget)
 
     def set_remove_behaviour(self, mode: str) -> None:
-        """sets the remove hehaviour
+        """Set the remove hehaviour.
 
         What tab should be set as current when removeTab is called
         if the removed tab is also the current tab.
@@ -110,7 +108,7 @@ class TabBar(QtWidgets.QTabBar):
         self.setSelectionBehaviorOnRemove(REMOVE_BEHAVIOURS[mode])
 
     def get_remove_behaviour(self) -> str:
-        """returns remove behaviour
+        """Return remove behaviour.
 
         possible values are "left_tab", "right_tab", "previous_tab"
 
@@ -120,7 +118,7 @@ class TabBar(QtWidgets.QTabBar):
         return REMOVE_BEHAVIOURS.inv[self.selectionBehaviorOnRemove()]
 
     def set_elide_mode(self, mode: str) -> None:
-        """set elide mode
+        """Set elide mode.
 
         Valid values are "left", "right", "middle", "none"
 
@@ -135,7 +133,7 @@ class TabBar(QtWidgets.QTabBar):
         self.setElideMode(ELIDE_MODES[mode])
 
     def get_elide_mode(self) -> str:
-        """returns elide mode
+        """Return elide mode.
 
         possible values are "left", "right", "middle", "none"
 
