@@ -1,11 +1,9 @@
 # -*- coding: utf-8 -*-
-"""
-"""
 
 from contextlib import contextmanager
 import functools
 import operator
-from typing import Dict, Iterator, Callable, Optional, Union, Any
+from typing import Dict, Iterator, Callable, Optional, Union, Any, Generator
 
 from qtpy import QtCore, QtGui, QtWidgets
 import qstylizer.parser
@@ -83,14 +81,39 @@ QtWidgets.QWidget.__bases__ = (core.Object, QtGui.QPaintDevice)
 
 class Widget(QtWidgets.QWidget):
     def __repr__(self) -> str:
-        return f"{self.__class__.__name__}: {self.__getstate__()}"
+        return f"{self.__class__.__name__}: {self.serialize_fields()}"
 
-    def __getstate__(self) -> Dict[str, Any]:
+    def __pretty__(
+        self, fmt: Callable[[Any], Any], **kwargs: Any
+    ) -> Generator[Any, None, None]:
+        """Provide a human readable representations of objects.
+
+        Used by devtools (https://python-devtools.helpmanual.io/).
+        """
+        yield self.__class__.__name__ + "("
+        yield 1
+        for k, v in self.serialize().items():
+            yield f"{k}={v!r}"
+            yield 0
+        yield -1
+        yield ")"
+
+    def serialize_fields(self) -> Dict[str, Any]:
+        icon = gui.Icon(self.windowIcon())
         return dict(
-            layout=self.layout(),
+            layout=self.layout() if isinstance(self.layout(), widgets.Layout) else None,
             size_policy=self.get_size_policy(),
             accessible_name=self.accessibleName(),
             tooltip=self.toolTip(),
+            tooltip_duration=self.toolTipDuration(),
+            window_title=self.windowTitle(),
+            enabled=self.isEnabled(),
+            visible=self.isVisible(),
+            icon=icon if not icon.isNull() else None,
+            modality=self.get_modality(),
+            whats_this=self.whatsThis(),
+            contextmenu_policy=self.get_contextmenu_policy(),
+            focus_policy=self.get_focus_policy(),
             statustip=self.statusTip(),
         )
 
@@ -109,7 +132,7 @@ class Widget(QtWidgets.QWidget):
             super().resize(*size)
 
     def set_icon(self, icon: gui.icon.IconType) -> None:
-        """set the window icon
+        """Set the window icon.
 
         Args:
             icon: icon to use
@@ -221,7 +244,7 @@ class Widget(QtWidgets.QWidget):
         self.setAttribute(ATTRIBUTES[attribute], state)
 
     def set_modality(self, modality: str = "window") -> None:
-        """set modality for the dialog
+        """Set modality for the dialog.
 
         Valid values for modality: "none", "window", "application"
 
@@ -236,7 +259,7 @@ class Widget(QtWidgets.QWidget):
         self.setWindowModality(MODALITIES[modality])
 
     def get_modality(self) -> str:
-        """get the current modality modes as a string
+        """Get the current modality modes as a string.
 
         Possible values: "none", "window", "application"
 
@@ -249,7 +272,7 @@ class Widget(QtWidgets.QWidget):
     def set_size_policy(
         self, horizontal: Optional[str] = None, vertical: Optional[str] = None
     ) -> None:
-        """sets the sizes policy
+        """Set the sizes policy.
 
         possible values for both parameters are "fixed", "minimum", "maximum",
         "preferred", "expanding", "minimum_expanding" and "ignored"
@@ -302,7 +325,7 @@ class Widget(QtWidgets.QWidget):
         self.setFont(font)
 
     def set_contextmenu_policy(self, policy: str) -> None:
-        """set contextmenu policy for given item view
+        """Set contextmenu policy for given item view.
 
         Allowed values are "none", "prevent", "default", "actions", "custom"
 
@@ -317,7 +340,7 @@ class Widget(QtWidgets.QWidget):
         self.setContextMenuPolicy(CONTEXT_POLICIES[policy])
 
     def get_contextmenu_policy(self) -> str:
-        """returns current contextmenu policy
+        """Return current contextmenu policy.
 
         Possible values: "none", "prevent", "default", "actions", "custom"
 
